@@ -1,6 +1,7 @@
       subroutine cphits2cos(ityp, ktyp, code, subcode, charge)
 !    this is probably not used. (but next sub is used)
       implicit none
+#include "Zcode.h"
       integer,intent(in)::ityp   !  phits code
       integer,intent(in)::ktyp   !  KF code (but A>1, diff)
       integer,intent(out)::code  !  cosmos  code
@@ -10,6 +11,11 @@
          code = 9   ! = kgnuc
          charge =  ktyp/1000000
          subcode =ktyp- charge*1000000
+         if( subcode <= 1 ) then  
+!               proton may  come out as  1000001
+            code = knuc
+            subcode = regptcl
+         endif   
       else
          call ckf2cos(ktyp, code, subcode, charge)
       endif
