@@ -17,10 +17,10 @@ c       interface to sophia (photo hadron production routin)
 !
 c E0 = energy of incident proton (in lab frame) [in GeV]
 c L0 = code number of the incident nucleon (L0=13: proton, L0=14: neutron)
-c     common with   sofia
+c     common with   sofia (S_PLIST --> SS_PLIST; why?  see Readme)
       real(8)::P
       integer:: LLIST, NP, Ideb
-      COMMON /S_PLIST/ P(2000,5), LLIST(2000), NP, Ideb
+      COMMON /SS_PLIST/ P(2000,5), LLIST(2000), NP, Ideb
 
 
       integer:: ic 
@@ -32,8 +32,9 @@ c     common with   sofia
       integer,save::imode
       integer,intent(out):: mode
       integer:: i
-!      real(8)::sumTE
-
+c///////////
+c      real(8)::sumTE
+c//////////
 
       if( first ) then
          call setDecayCond
@@ -47,6 +48,11 @@ c     common with   sofia
       endif
 !           fix target (p or n)
       call cfxTgtChg(massN, atomicN, ic)
+!///////////////
+c      write(0,*) 'csofia: pj.E=', pj.fm.p(4)
+c      write(0,*) ' tgt ic =',ic
+!/////////////////
+      
 
       if(ic == 1) then
          L0 = 13                ! p       
@@ -68,8 +74,12 @@ c//////
 c      write(0,*) 'calling sofiaEvent=', L0,E0, eps, theta
 c///////
       call sofiaEvent(L0, E0, eps, theta, imode)
-
-!      sumTE = 0.
+c///////////
+c      write(0,*) ' imode =', imode
+c///////////////
+c//////////////////
+c      sumTE = 0.
+c///////////////
 
       do i = 1, NP
          call csib2cos(LLIST(i), a(i))
@@ -77,13 +87,15 @@ c///////
          a(i).fm.p(2) = -P(i,2)   ! to make it +, invert sign
          a(i).fm.p(3) = -P(i,3)
          a(i).fm.p(4) =  P(i,4)
-!         sumTE = sumTE + P(i,4)
+c/////////////
+c         sumTE = sumTE + P(i,4)
+c/////////////
        enddo
 !c//////////
-!       if( abs( sumTE / (eps+E0) - 1.) > 0.005 ) then
-!          write(*,'(a,1p,2g13.4, i6)'  )
-!     *      'errgp ', eps,  (sumTE / (eps+E0) - 1.), NP 
-!       endif
+c       if( abs( sumTE / (eps+E0) - 1.) > 0.005 ) then
+c          write(*,'(a,1p,2g13.4, i6)'  )
+c     *      'errgp ', eps,  (sumTE / (eps+E0) - 1.), NP 
+c       endif
 !c/////////
        call crot3mom( pj, a, NP)
        ntp = NP
