@@ -20,7 +20,7 @@
       pj.fm.p(2) = 0.
       pj.fm.p(3) = eps
       pj.fm.p(4) =  eps
-      write(*,*)
+      write(*,'(a)')
      *   "# ev#  code subcode chg  Pz/P0 Px Py Pz E mode N"
       do  nev=1, nevent
          call csofia(A, Z, pj, work, ntp)
@@ -42,6 +42,6 @@
      *         work(j).fm.p(4),  Imode, ntp
          enddo
       enddo
-       write(*,*)
+       write(*,'(a)')
      *   "# ev#  code subcode chg  Pz/P0 Px Py Pz E mode N"
        END
