@@ -272,7 +272,6 @@ c          skip to the end of previous write
 
       fn = ' '
       fn = fnin
-
       j = index( fn, '$')
       do while ( j > 0 ) 
          call creplst( fn, j, '$')
@@ -323,6 +322,7 @@ c          skip to the end of previous write
       character*64 replst   ! to contain hostname, etc to replace %, # of or @
       integer ir(2)
       character*16 envname
+      character*256 fntemp
       integer jp
 
       jj = 1
@@ -340,6 +340,7 @@ c                 $(USER) style
                   stop
                endif
                jj = jj + 1
+               jj = jj-j+1
             else
                write(0,*) ' $( is used in file name  fn=',fn
                write(0,*) ' but  no counterpart ) '
@@ -363,6 +364,7 @@ c                  USER
                write(0,*) ' Env. =', envname, ' not exist'
                stop
             endif
+            jj = jj - j + 1
          endif
       endif
 
@@ -427,10 +429,12 @@ c                  USER
          endif
       endif
       if( j .eq. 1 ) then
-         fn = replst(1:leng)//fn(j+jj:klena(fn))
+         fntemp = replst(1:leng)//fn(j+jj:klena(fn))
+         fn = fntemp
       else
-         fn =
+         fntemp =
      *        fn(1:j-1)//replst(1:leng)//fn(jj+j:)
+         fn = fntemp
       endif
 
       end
