@@ -206,8 +206,8 @@ module modTargetFrag
          endif
       enddo
       if( indexpA1 == 0 ) then
-         write(0,*) ' warning: input pA=',pA, 'too large for ', &
-          & ' cSampFragNHR'
+!         write(0,*) ' warning: input pA=',pA, 'too large for ', &
+!          & ' cSampFragNHR'
          indexpA1 = dpjA
          exactpA = .true.
       endif
@@ -234,8 +234,8 @@ module modTargetFrag
          endif
       enddo
       if( indextA1 == 0 ) then
-         write(0,*) ' warning: input pA=',tA, 'too large for ', &
-          & ' cSampFragNHR'
+!         write(0,*) ' warning: input pA=',tA, 'too large for ', &
+!          & ' cSampFragNHR'
          indextA1= dtgA
          exacttA= .true.
       endif
@@ -286,8 +286,8 @@ module modTargetFrag
          y0 = dpjA2pjA(pAi(1))
          hx = dtgA2tgA(tAi(2))- x0
          hy = dpjA2pjA(pAi(2))- y0
-         x = tA
-         y = pA
+         x = min(tA, dtgA2tgA(dtgA))
+         y = min(pA, dpjA2pjA(dpjA))
          call c4ptdi(ava(1,1,i),  x0, y0, hx, hy, x, y, ansav(i))
          call c4ptdi(rmsa(1,1,i),  x0, y0, hx, hy, x, y, ansrms(i))
 !/////////////
@@ -422,8 +422,8 @@ module modTargetFrag
          endif
       enddo
       if( indexpA1 == 0 ) then
-         write(0,*) ' warning: input pA=',pA, 'too large for ', &
-          & ' cSampFragNHR'
+!         write(0,*) ' warning: input pA=',pA, 'too large for ', &
+!          & ' cSampFragNHR'
          indexpA1 = dpjA
          exactpA = .true.
       endif
@@ -445,8 +445,8 @@ module modTargetFrag
          endif
       enddo
       if( indextA1 == 0 ) then
-         write(0,*) ' warning: input tA=',tA, 'too large for ', &
-          & ' cSampFragNHR'
+!         write(0,*) ' warning: input pA=',tA, 'too large for ', &
+!          & ' cSampFragNHR'
          indextA1= dtgA
          exacttA= .true.
       endif
@@ -489,8 +489,8 @@ module modTargetFrag
          y0 = dpjA2pjA(pAi(1))
          hx = dtgA2tgA(tAi(2))- x0
          hy = dpjA2pjA(pAi(2))- y0
-         x = tA
-         y = pA
+         x = min(tA, dtgA2tgA(dtgA))
+         y = min(pA, dpjA2pjA(dpjA))
          call c4ptdi(ava(1,1,1),  x0, y0, hx, hy, x, y, ansav(i))
       enddo
 
