@@ -382,12 +382,12 @@ c            remove blanks
       elseif( pj.code >= klambda .and. pj.code <= klambdac ) then
 c          regard it as neutron                                                
          call cmkptc(knuc, -1, 0, pj)
-         call ce2p(pj)
+         call cadjm(pj, pj)
          symb = 'n'
       elseif( pj.code == kbomega ) then
 c         very rare: regard it as proton
          call cmkptc(knuc, -1, 1, pj)
-         call ce2p(pj)
+         call cadjm(pj, pj)
          symb = 'p'
       else
          write(0,*) 'code=',pj.code, ' charge=',pj.charge
@@ -465,6 +465,7 @@ c///////////
 !            endif
 !         endif
 !      endif
+
       do i = 1, nv
          if( k(1,i) <= 11 .and. k(1,i) >= 0  ) then  ! avoid dead ptcl 
 !            if( ia /= 1 .or. pj.code >= kgnuc ) then  ! target is A or proj iS A 
@@ -543,6 +544,7 @@ c            write(*,*) i, k(2,i), p(1,i), p(2,i), p(3,i),
 c     *             p(4,i), p(5,i)
          endif
       enddo
+
 c///////////////
 c      if( pj.fm.p(4) > inci.fm.p(4)*0.98 ) then
 c         write(*,*) 'pjTE=',pjTE, ' pj. =',pj.fm.p(4)
