@@ -19,11 +19,10 @@ c
       real*8  elemA(noOfElem), elemS(noOfElem, nxsec), sigma(nxsec)
       real*8  cumsigma(noOfElem, nxsec), elemZ(noOfElem)
       real*8  No(noOfElem)
-      real*8  u, tgA
+      real*8  u, tgA, tgZ
       data elemA/14.0d0, 16.0d0, 40.0d0/
       data   No/1.56d0, 0.42d0, 0.01d0/
       data   elemZ/7.0d0, 8.0d0, 18.0d0/
-
 c     save elemA, No, elemZ
       save
 
@@ -127,12 +126,20 @@ c       i          1                         nxsec
 c          we need xs on the target nucleon for bmax; for other models
 c          need not do this
          tgA =  TargetNucleonNo 
+         tgZ =  TargetProtonNo
 c         if(TrackBefMove.p.code <= knuc  .and. 
 c     *     (TrackBefMove.p.fm.p(4)-TrackBefMove.p.mass)  < 10.d0) then
          if(TrackBefMove.p.code <= knuc ) then
-            call ctotx(TrackBefMove.p, tgA,  TargetXs)
+            if( JamXs == 1 ) then
+               call ctotx(TrackBefMove.p, tgA,  TargetXs)
+            elseif( JamXs == 0 ) then
+               call cinelx(TrackBefMove.p,  tgA, tgZ, TargetXs)
+            else
+               write(0,*) ' JamXs =',JamXs,' not usable in cixsec'
+               stop
+            endif
          else
-            call cinelx(TrackBefMove.p,  tgA, TargetXs)
+            call cinelx(TrackBefMove.p, tgA, tgZ, TargetXs)
          endif
       endif
 c///////////////////
