@@ -101,7 +101,7 @@ c            use kaon
          else
             call cmkptc(kkaon, 0, icg, MovedTrack.p)
          endif
-         call ce2p(MovedTrack.p)
+         call ce2p(MovedTrack)
          call chAcol(MovedTrack.p, TargetNucleonNo, TargetProtonNo,
      *     Pwork, Nproduced)
       else
