@@ -163,6 +163,8 @@ c #include  "Zelemagp.h"
          call cmfpjam(xs, mfp)
       elseif(ActiveMdl .eq. 'qgsjet2') then
          call cmfpqgsjet2(xs, mfp)
+      elseif(ActiveMdl .eq. 'epos') then   
+         call cmfpepos(xs, mfp)
       elseif(ActiveMdl .eq. 'gheisha') then
          call cmfpgheisha(xs, mfp)
       elseif(ActiveMdl .eq. 'incdpm3') then
@@ -370,6 +372,63 @@ c                   use proton
       endif
       end
 
+
+      subroutine cmfpepos(xs, mfp)
+      implicit none
+#include  "Zglobalc.h"
+#include  "Zcode.h"
+#include  "Ztrackp.h"
+#include  "Ztrack.h"
+#include  "Ztrackv.h"
+#include  "Zevhnp.h"
+#include  "Zevhnv.h"
+#include  "Zcmuint.h"
+      real*8   xs, mfp
+
+      logical here
+      record /ptcl/ proj, tg
+      integer ka, ica, ia, iz
+      real*8 u
+      
+      here = .false.
+      proj = TrackBefMove.p
+      ka = proj.code
+      ica = proj.charge
+      if( ka .eq. kpion) then
+         here =.true.
+      elseif(ka. eq. knuc) then
+         here = .true.
+      elseif(ka .eq. kkaon) then
+         here = .true.
+      elseif(ka .eq. kgnuc) then
+         here = .true.
+      elseif(ka .eq. kgzai .or. ka .eq. ksigma .or.
+     *     ka .eq. kbomega    .or. ka .eq.  klambda ) then
+         here = .true.
+         here = .true.
+c                   use proton
+         call cmkptc(knuc, -1, 1, proj)
+      endif
+      if(here ) then
+         ia = TargetMassN
+         iz = TargetAtomicN
+         call rndc(u)
+         if(u .lt.  TargetMassN - ia) then
+            ia = ia + 1
+         endif
+         call cmkptc(kgnuc, ia, iz, tg)
+         tg.fm.p(1) = 0.
+         tg.fm.p(2) = 0.
+         tg.fm.p(3) = 0.
+         tg.fm.p(4) = tg.mass
+         call ceposIniOneEvent(proj, tg, xs)
+         mfp = A2deninv*TargetMassN/xs   ! in kg/m2
+      else
+         call cmfpother(xs, mfp)
+      endif
+      end
+
+
       subroutine cmfpincdpm3(xs,mfp)
       implicit none
 #include  "Zglobalc.h"
